## 开盘啦题材成分

接口：kpl_concept_cons

描述：获取开盘啦概念题材的成分股

限量：单次最大3000条，可根据代码和日期循环获取全部数据

积分：5000积分可提取数据，具体请参阅积分获取办法 

注：开盘啦是一个优秀的专业打板app，有兴趣的用户可以自行下载安装。本接口仅限用于量化研究，如需商业用途，请自行联系开盘APP官方。

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| trade_date | str | N | 交易日期（YYYYMMDD格式） |
| ts_code | str | N | 题材代码（xxxxxx.KP格式） |
| con_code | str | N | 成分代码（xxxxxx.SH格式） |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 题材ID |
| name | str | Y | 题材名称 |
| con_name | str | Y | 股票名称 |
| con_code | str | Y | 股票代码 |
| trade_date | str | Y | 交易日期 |
| desc | str | Y | 描述 |
| hot_num | None | Y | 人气值 |

接口用法

```python
pro = ts.pro_api()

df = pro.kpl_concept_cons(trade_date='20241014')
```

数据样例

```python
ts_code      name     ts_name con_code trade_date
0     000111.KP  化债概念    信达地产  600657.SH   20241014
```